@@ -6,21 +6,22 @@
 #' @param link link function, default"logit", choose from "logit", "cloglog", "loglog", "probit", and "identity"(for regular linear regression)
 #'
 #' @return
-#' Fisher information matrix given X and model parameter beta
+#' object of class "matrix_output", Fisher information matrix given X and model parameter beta
 #' @export
 #'
 #' @examples
 #' w = c(1/3,1/3, 1/3)
 #' beta = c(0.5, 0.5, 0.5)
 #' X = matrix(data=c(1,-1,-1,1,-1,1,1,1,-1), byrow=TRUE, nrow=3)
-#' Fdet_func_GLM(w=w, beta=beta, X=X, link='logit')
-#'
-#'
+#' F_func_GLM(w=w, beta=beta, X=X, link='logit')
 #'
 
 
+
 F_func_GLM = function(w, beta, X, link="logit"){
   W_matrix=W_func_GLM(X=X, beta=beta, link=link)
   Fisher_matrix = t(X * (w*W_matrix)) %*% X
+  #define S3 class
+  class(Fisher_matrix) <- "matrix_output"
   return(Fisher_matrix)
 }
